@@ -4,4 +4,4 @@ set -x
 
 autoflake --remove-all-unused-imports --recursive --remove-unused-variables --in-place tcpb tests examples --exclude=__init__.py
 black tcpb tests examples
-isort tcbp tests examples
+isort tcpb tests examples
